<?php
/*
Plugin Name: Gravatar Shortcode
Plugin URI: https://example.com/
Description: A simple plugin to add a Gravatar anywhere in your posts using a shortcode.
Version: 1.1
Author: Your Name
Author URI: https://example.com/
License: GPL2
*/

// Ensure the file is not accessed directly
if (!defined('ABSPATH')) {
    exit;
}

// Function to generate the Gravatar HTML
function generate_gravatar($atts) {
    // Extract attributes
    $atts = shortcode_atts(
        array(
            'email' => '',
            'size' => 80,
            'default' => 'mm',
            'rating' => 'g',
            'alt' => 'Gravatar'
        ), 
        $atts, 'gravatar'
    );

    // Generate the Gravatar URL
    $email_hash = md5(strtolower(trim($atts['email'])));
    $gravatar_url = sprintf(
        "https://www.gravatar.com/avatar/%s?s=%d&d=%s&r=%s",
        $email_hash,
        (int)$atts['size'],
        $atts['default'],
        $atts['rating']
    );

    // Return the Gravatar image HTML
    return sprintf(
        '<img src="%s" alt="%s" width="%d" height="%d" />',
        esc_url($gravatar_url),
        esc_attr($atts['alt']),
        (int)$atts['size'],
        (int)$atts['size']
    );
}

// Register the shortcode
add_shortcode('gravatar', 'generate_gravatar');

// Add menu item to admin panel
function gravatar_shortcode_menu() {
    add_menu_page(
        'Gravatar Shortcode', // Page title
        'Gravatar Shortcode', // Menu title
        'manage_options', // Capability
        'gravatar-shortcode', // Menu slug
        'gravatar_shortcode_admin_page', // Function to display the page
        'dashicons-admin-users', // Icon
        100 // Position
    );
}
add_action('admin_menu', 'gravatar_shortcode_menu');

// Display the admin page content
function gravatar_shortcode_admin_page() {
    ?>
    <div class="wrap">
        <h1>Gravatar Shortcode</h1>
        <p>Use the shortcode <code>[gravatar]</code> to display a Gravatar image in your posts. The shortcode supports the following attributes:</p>
        <ul>
            <li><code>email</code> (required): The email address associated with the Gravatar.</li>
            <li><code>size</code> (optional): The size of the Gravatar in pixels (default is 80).</li>
            <li><code>default</code> (optional): The default image to display if the email has no Gravatar (default is <code>mm</code>).</li>
            <li><code>rating</code> (optional): The maximum allowed rating (default is <code>g</code>).</li>
            <li><code>alt</code> (optional): The alt text for the image (default is <code>Gravatar</code>).</li>
        </ul>
        <h2>Example Usage:</h2>
        <p><code>[gravatar email="user@example.com" size="100" default="identicon" rating="pg" alt="User Gravatar"]</code></p>
    </div>
    <?php
}
?>
